Automatic Lidar and Ceilometer Framework (ALCF)
===============================================

ALCF is an open source command line tool for processing of automatic lidar and
ceilometer (ALC) data and intercomparison with atmospheric models such as
general circulation models (GCMs), numerical weather prediction models (NWP) and
reanalyses with a lidar simulator using the
[COPS](https://github.com/CFMIP/COSPv2.0) instrument simulator framework running
offline on model output. ALCs are vertically pointing atmospheric lidars,
measuring cloud and aerosol backscatter. The primary focus of ALCF are
atmospheric studies of cloud using ALC observations and model cloud validation.

Please see [alcf.peterkuma.net](https://alcf.peterkuma.net) for more
information.
